# GenerateBillingDocumentResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**process_id** | **str** | The Id of the process that handle the operation.  | [optional] 
**request_id** | **str** | Unique request identifier. If you need to contact us about a specific request, providing the request identifier will ensure the fastest possible resolution.  | [optional] 
**reasons** | [**List[FailedReason]**](FailedReason.md) |  | [optional] 
**success** | **bool** | Indicates whether the call succeeded.  | [optional] 
**credit_memos** | [**List[GenerateBillingDocumentResponseCreditMemo]**](GenerateBillingDocumentResponseCreditMemo.md) | Container for generated credit memos.  **Note:** This container is only available if you have [Invoice Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement) enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  | [optional] 
**invoices** | [**List[GenerateBillingDocumentResponseInvoice]**](GenerateBillingDocumentResponseInvoice.md) | Container for generated invoices.  | [optional] 

## Example

```python
from zuora_sdk.models.generate_billing_document_response import GenerateBillingDocumentResponse

# TODO update the JSON string below
json = "{}"
# create an instance of GenerateBillingDocumentResponse from a JSON string
generate_billing_document_response_instance = GenerateBillingDocumentResponse.from_json(json)
# print the JSON string representation of the object
print(GenerateBillingDocumentResponse.to_json())

# convert the object into a dict
generate_billing_document_response_dict = generate_billing_document_response_instance.to_dict()
# create an instance of GenerateBillingDocumentResponse from a dict
generate_billing_document_response_from_dict = GenerateBillingDocumentResponse.from_dict(generate_billing_document_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


